# caldav

This project is a CalDAV ([RFC4791](http://www.ietf.org/rfc/rfc4791.txt)) client library for Python.

 * [Pypi](http://pypi.python.org/pypi/caldav)
 * [Documentation](http://packages.python.org/caldav)

